==> video-android-3.2.1-sources.jar: com/twilio/video/LocalVideoTrackStats.java <==
/*
 * Copyright (C) 2017 Twilio, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.twilio.video;

public class LocalVideoTrackStats extends LocalTrackStats {
    /** Captured frame dimensions */
    public final VideoDimensions captureDimensions;

    /** Captured frame rate */
    public final int capturedFrameRate;

    /** Sent frame dimensions */
    public final VideoDimensions dimensions;

    /** Sent frame rate */
    public final int frameRate;

    LocalVideoTrackStats(
            String trackSid,
            int packetsLost,
            String codec,
            String ssrc,
            double timestamp,
            long bytesSent,
            int packetsSent,
            long roundTripTime,
            VideoDimensions captureDimensions,
            VideoDimensions dimensions,
            int capturedFrameRate,
            int frameRate) {
        super(trackSid, packetsLost, codec, ssrc, timestamp, bytesSent, packetsSent, roundTripTime);
        this.captureDimensions = captureDimensions;
        this.dimensions = dimensions;
        this.frameRate = frameRate;
        this.capturedFrameRate = capturedFrameRate;
    }
}

==> video-android-5.0.1-sources.jar: com/twilio/video/LocalVideoTrackStats.java <==
/*
 * Copyright (C) 2017 Twilio, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.twilio.video;

import android.support.annotation.NonNull;

public class LocalVideoTrackStats extends LocalTrackStats {
    /** Captured frame dimensions */
    @NonNull public final VideoDimensions captureDimensions;

    /** Captured frame rate */
    public final int capturedFrameRate;

    /** Sent frame dimensions */
    @NonNull public final VideoDimensions dimensions;

    /** Sent frame rate */
    public final int frameRate;

    LocalVideoTrackStats(
            String trackSid,
            int packetsLost,
            String codec,
            String ssrc,
            double timestamp,
            long bytesSent,
            int packetsSent,
            long roundTripTime,
            @NonNull VideoDimensions captureDimensions,
            @NonNull VideoDimensions dimensions,
            int capturedFrameRate,
            int frameRate) {
        super(trackSid, packetsLost, codec, ssrc, timestamp, bytesSent, packetsSent, roundTripTime);
        this.captureDimensions = captureDimensions;
        this.dimensions = dimensions;
        this.frameRate = frameRate;
        this.capturedFrameRate = capturedFrameRate;
    }
}
